#!/opt/puppetlabs/puppet/bin/ruby
#
#
# See the file "LICENSE" for the full license governing this code.
#
#

require 'json'
require 'open3'
require 'puppet'
Puppet.initialize_settings
require 'easy_type'
require 'puppet_x/enterprisemodules/weblogic/core'

params = JSON.parse(STDIN.read)
domain = params.fetch('domain') { 'default'}
skip   = params.fetch('skip')   { []}

STOP_STATES  = [
  'SHUTTING-DOWN',
  'SUSPENING',
  'FORCE_SUSPEND',
  'SHUTDOWN'
]

begin
  result = {}
  wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(domain)
  begin
    # Check if the domain exists
    wls_config.validate
  rescue ArgumentError => e
    result[:_error] = { 
      msg: e.message,
      kind: "enterprisemodules-wls_config/unknown_domain"
    }
    puts result.to_json
    raise e
  end
  admin_server = wls_config.admin_server
  state = wls_config.get("/ServerLifeCycleRuntimes/#{admin_server}/State", 'domainRuntime')
  if STOP_STATES.include?(state)
    result['already_stopped_managed_servers'] ||= []
    result['already_stopped_managed_servers'] << admin_server
  else
    wls_config.stop_server(admin_server)
    result['stopped_managed_servers'] ||= []
    result['stopped_managed_servers'] << admin_server
  end
  puts result.to_json

end
